@@ -1,13 +1,13 @@
 package Finance::Bank::ID::BPRKS;
 
-use 5.010;
+use 5.010001;
 use Moo;
 use DateTime;
 use Log::Any '$log';
 
 use Parse::Number::ID qw(parse_number_id);
 
-our $VERSION = '0.01'; # VERSION
+our $VERSION = '0.02'; # VERSION
 
 extends 'Finance::Bank::ID::Base';
 
@@ -437,17 +437,19 @@ sub _ps_get_transactions {
 1;
 # ABSTRACT: Check your BPR KS accounts from Perl
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Finance::Bank::ID::BPRKS - Check your BPR KS accounts from Perl
 
 =head1 VERSION
 
-version 0.01
+This document describes version 0.02 of Finance::Bank::ID::BPRKS (from Perl distribution Finance-Bank-ID-BPRKS), released on 2014-05-17.
 
 =head1 SYNOPSIS
 
@@ -638,6 +640,10 @@ current net banking login.
 Return balance for specified account, or the default account if C<$account> is
 not specified.
 
+=head2 list_cards()
+
+List ATM cards. Not yet implemented.
+
 =head2 get_statement(%args) => $stmt
 
 Get account statement. %args keys:
@@ -724,16 +730,31 @@ Additional notes:
 The method can also handle some copy-pasted text from the GUI browser, but this
 is no longer documented or guaranteed to keep working.
 
+=head1 HOMEPAGE
+
+Please visit the project's homepage at L<https://metacpan.org/release/Finance-Bank-ID-BPRKS>.
+
+=head1 SOURCE
+
+Source repository is at L<https://github.com/sharyanto/perl-Finance-Bank-ID-BPRKS>.
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Finance-Bank-ID-BPRKS>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =head1 AUTHOR
 
 Steven Haryanto <stevenharyanto@gmail.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Steven Haryanto.
+This software is copyright (c) 2014 by Steven Haryanto.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
